bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGamma.lower_bound_contribution
=====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGamma.lower_bound_contribution